@@ -97,6 +97,7 @@ class qhtml:
         _preview_scripts_loaded = False
         for _obj_element in self.all:
             # print("ajax code for " + str(_obj_element.type))
+
             if _obj_element.has_preview() and _preview_scripts_loaded is False:
                 self.__get_preview_scripts()
                 _preview_scripts_loaded = True
@@ -478,6 +479,40 @@ class qhtml:
         def get_tag_close(self):
             return "</" + self.type + ">"
 
+        def set_text_code_block(self, _str, text_color=False, parentheses_color=False, main_text_color=False, background_color=False):
+
+            if self.type != 'pre':
+                print('set_text_code_block type error. Should be used on a "pre" type.\nYou used it on a ' + self.type)
+                return False
+
+            replace = {
+                ':': '<span style="color:gray;">:</span>',
+                '(': '<span style="color:orange;">(<span style="color:yellow;">',
+                ')': '</span>)</span>',
+            }
+
+            if text_color and parentheses_color:
+                replace['('] = '<span style="color:' + parentheses_color + ';">(<span style="color:' + text_color + ';">'
+            elif text_color:
+                replace['('] = '<span style="color:orange;">(<span style="color:' + text_color + ';">'
+            elif parentheses_color:
+                replace['('] = '<span style="color:' + parentheses_color + ';">(<span style="color:yellow;">'
+
+            for k in replace:
+                v = replace[k]
+                if k in _str:
+                    _str = _str.replace(k, v)
+
+            if not background_color:
+                background_color = 'gray'
+
+            if not main_text_color:
+                main_text_color = 'white'
+
+            self.innerText = '<p style="margin:0px;padding:6px;color:' + main_text_color + ';background-color:' + background_color + ';">' + _str + '</p>'
+
+            return self
+
         # Attempts to set the text of an object
         # returns: itself/object
 
@@ -584,8 +619,11 @@ class qhtml:
 
             return self
 
-        def html(self):
-            return self.get_tag_open() + self.innerText + self.innerHTML + self.get_tag_close()
+        def html(self,set_clip_board=False):
+            html = self.get_tag_open() + self.innerText + self.innerHTML + self.get_tag_close()
+            if set_clip_board:
+                self.parent.clip_put(html)
+            return html
 
         # Get parent class
         # returns: parent/obj
@@ -1117,4 +1155,4 @@ class qhtml:
                     print('Pickles Loaded - > ' + str(_templates))
                     return _templates
 
-            return False
\ No newline at end of file
+            return False
